@@ -494,8 +494,11 @@ def _create_filehandle(name, mode, position, closed, open, strictio, fmode, fdat
         # treat x mode as w mode
         if "x" in mode and sys.hexversion < 0x03030000:
             raise ValueError("invalid mode: '%s'" % mode)
-
-        if not os.path.exists(name):
+        try:
+            exists = os.path.exists(name)
+        except:
+            exists = False
+        if not exists:
             if strictio:
                 raise FileNotFoundError("[Errno 2] No such file or directory: '%s'" % name)
             elif "r" in mode and fmode != FILE_FMODE:
@@ -537,6 +540,8 @@ def _create_filehandle(name, mode, position, closed, open, strictio, fmode, fdat
                     r = getattr(r, "raw", r)
                     r.name = name
                 else:
+                    if not HAS_CTYPES:
+                        raise ImportError("No module named 'ctypes'")
                     class FILE(ctypes.Structure):
                         _fields_ = [("refcount", ctypes.c_long),
                                     ("type_obj", ctypes.py_object),
@@ -548,8 +553,6 @@ def _create_filehandle(name, mode, position, closed, open, strictio, fmode, fdat
                             ("ob_refcnt", ctypes.c_int),
                             ("ob_type", ctypes.py_object)
                             ]
-                    if not HAS_CTYPES:
-                        raise ImportError("No module named 'ctypes'")
                     ctypes.cast(id(f), ctypes.POINTER(FILE)).contents.name = name
                     ctypes.cast(id(name), ctypes.POINTER(PyObject)).contents.ob_refcnt += 1
                 assert f.name == name
@@ -655,7 +658,7 @@ def _getattr(objclass, name, repr_str):
 
 def _get_attr(self, name):
     # stop recursive pickling
-    return getattr(self, name)
+    return getattr(self, name, None) or getattr(__builtin__, name)
 
 def _dict_from_dictproxy(dictproxy):
     _dict = dictproxy.copy() # convert dictproxy to dict
@@ -696,7 +699,9 @@ def save_function(pickler, obj):
         if getattr(pickler, '_recurse', False):
             # recurse to get all globals referred to by obj
             from .detect import globalvars
-            globs = globalvars(obj, recurse=True)
+            globs = globalvars(obj, recurse=True, builtin=True)
+            if obj in globs.values(): #ABORT: use _recurse=False
+                globs = obj.__globals__ if PY3 else obj.func_globals
         else:
             globs = obj.__globals__ if PY3 else obj.func_globals
         if PY3:
@@ -866,8 +871,16 @@ def save_functor(pickler, obj):
 @register(BuiltinMethodType)
 def save_builtin_method(pickler, obj):
     if obj.__self__ is not None:
-        log.info("B1: %s" % obj)
-        pickler.save_reduce(_get_attr, (obj.__self__, obj.__name__), obj=obj)
+        if obj.__self__ is __builtin__:
+            module = 'builtins' if PY3 else '__builtin__'
+            log.info("B1: %s" % obj)
+        else:
+            module = obj.__self__
+            log.info("B3: %s" % obj)
+        _recurse = pickler._recurse
+        pickler._recurse = False
+        pickler.save_reduce(_get_attr, (module, obj.__name__), obj=obj)
+        pickler._recurse = _recurse
     else:
         log.info("B2: %s" % obj)
         StockPickler.save_global(pickler, obj)
@@ -1032,6 +1045,7 @@ def save_module(pickler, obj):
                      "prefix", "real_prefix"]
             builtin_mod = any([obj.__file__.startswith(getattr(sys, name))
                            for name in names if hasattr(sys, name)])
+            builtin_mod = builtin_mod or 'site-packages' in obj.__file__
         else:
             builtin_mod = True
         if obj.__name__ not in ("builtins", "dill") \
