@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
-# Copyright (c) 2008-2014 California Institute of Technology.
+# Copyright (c) 2008-2015 California Institute of Technology.
 # License: 3-clause BSD.  The full license text is available at:
 #  - http://trac.mystic.cacr.caltech.edu/project/pathos/browser/dill/LICENSE
 
 import dill
+dill.settings['recurse'] = True
 import weakref
 
 class _class:
@@ -58,6 +59,7 @@ xp = weakref.proxy(x)
 
 objlist = [r,dr,m,dm,fr,xr, p,dp,t,dt, c,dc,d,dd, fp,xp]
 
+#dill.detect.trace(True)
 for obj in objlist:
   res = dill.detect.errors(obj)
   if res:
